==> haskell-should-not-typecheck-2.1.0-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-should-not-typecheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: should-not-typecheck
version: 2.1.0
id: should-not-typecheck-2.1.0-HttYi4Gl5qG6QRSy4CgfJ6
key: should-not-typecheck-2.1.0-HttYi4Gl5qG6QRSy4CgfJ6
license: BSD-3-Clause
maintainer: message.me.on@github.com
author: Callum Rogers
homepage: http://github.com/CRogers/should-not-typecheck
synopsis: A HUnit/hspec assertion library to verify that an expression does not typecheck
description:
    For examples and an introduction to the library please take a look at the <https://github.com/CRogers/should-not-typecheck#should-not-typecheck- README> on github.
category: Testing
abi: 6ab135ac0faddce7a23da71993cb1b6b
exposed: True
exposed-modules:
    Test.ShouldNotTypecheck
import-dirs: /usr/lib/ghc-8.6.1/site-local/should-not-typecheck-2.1.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/should-not-typecheck-2.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/should-not-typecheck-2.1.0
hs-libraries: HSshould-not-typecheck-2.1.0-HttYi4Gl5qG6QRSy4CgfJ6
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj base-4.12.0.0 deepseq-1.4.4.0
haddock-interfaces: /usr/share/doc/haskell-should-not-typecheck/html/should-not-typecheck.haddock
haddock-html: /usr/share/doc/haskell-should-not-typecheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-should-not-typecheck-2.1.0-24-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-should-not-typecheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: should-not-typecheck
version: 2.1.0
id: should-not-typecheck-2.1.0-5C05KrY2j0WASZlCVlaNXJ
key: should-not-typecheck-2.1.0-5C05KrY2j0WASZlCVlaNXJ
license: BSD-3-Clause
maintainer: message.me.on@github.com
author: Callum Rogers
homepage: http://github.com/CRogers/should-not-typecheck
synopsis: A HUnit/hspec assertion library to verify that an expression does not typecheck
description:
    For examples and an introduction to the library please take a look at the <https://github.com/CRogers/should-not-typecheck#should-not-typecheck- README> on github.
category: Testing
abi: 7f7018e175a7fcad0179f3fbfa55352d
exposed: True
exposed-modules:
    Test.ShouldNotTypecheck
import-dirs: /usr/lib/ghc-8.6.1/site-local/should-not-typecheck-2.1.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/should-not-typecheck-2.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/should-not-typecheck-2.1.0
hs-libraries: HSshould-not-typecheck-2.1.0-5C05KrY2j0WASZlCVlaNXJ
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj base-4.12.0.0 deepseq-1.4.4.0
haddock-interfaces: /usr/share/doc/haskell-should-not-typecheck/html/should-not-typecheck.haddock
haddock-html: /usr/share/doc/haskell-should-not-typecheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
